#
# spec file for package gigedit
#
# Copyright (c) 2020 Packman Team <packman@links2linux.de>
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/
#


Name:           gigedit
Version:        1.1.1
Release:        pm152.4.4
Summary:        Instrument editor for gig files
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Utilities
URL:            https://www.linuxsampler.org/
Source0:        https://download.linuxsampler.org/packages/%{name}-%{version}.tar.bz2
Source1:        %{name}.desktop
Source2:        sfz.png
BuildRequires:  automake
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  xsltproc
BuildRequires:  perl(XML::Parser)
BuildRequires:  pkgconfig(gig) >= 4.1.0
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtkmm-3.0)
BuildRequires:  pkgconfig(linuxsampler) >= 2.1.0
BuildRequires:  pkgconfig(sigc++-2.0)
BuildRequires:  pkgconfig(sndfile) >= 1.0.11
ExclusiveArch:  %{ix86} x86_64
%ifarch armv6l armv6hl
BuildRequires:  -raspberrypi-userland
BuildRequires:  Mesa-libEGL1
BuildRequires:  pkgconfig(egl)
%endif

%description
Instrument editor for Gigasampler files gigedit is an instrument editor
allowing to modify existing Gigasampler files, as well as creating new
ones from scratch. The GUI is based on the GTK+ (gtkmm) toolkit. Even
though it is created as a subproject of the LinuxSampler project, it is
currently a completely independent stand-alone editor.

%prep
%autosetup

%build
autoreconf -fi
%configure --disable-static
%make_build

%install
%make_install

install -D -m 0644 %{SOURCE1} %{buildroot}%{_datadir}/applications/%{name}.desktop
install -D -m 0644 %{SOURCE2} %{buildroot}%{_datadir}/pixmaps/sfz.png

find %{buildroot} -type f -name "*.la" -delete -print

#No need in file
rm -f %{buildroot}%{_libdir}/%{name}/libgigedit.so

%suse_update_desktop_file %{name}

%find_lang %{name}

%files -f %{name}.lang
%license COPYING
%doc doc/quickstart/{*html,*png,*css} AUTHORS ChangeLog README NEWS
%{_bindir}/%{name}
%{_libdir}/%{name}
%dir %{_libdir}/linuxsampler
%dir %{_libdir}/linuxsampler/plugins
%{_libdir}/linuxsampler/plugins/libgigeditlinuxsamplerplugin.so
%{_datadir}/pixmaps/sfz.png
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/sfz.png
%exclude %{_datadir}/doc/%{name}

%changelog
* Wed Apr 22 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.1.1
  * Script Editor: Fixed some minor issues with vertical line
    number bar (which was editable, selectable and incorrectly
    displayed on new scripts).
  * Translation Fix: MacroEditor.cpp and MacrosSetup.cpp were
    not under translation control.
  * Spelling fixes (patch provided by Debian maintainer Jaromír
    Mikeš).
  * Added new main menu item "View" -> "Tooltips for Beginners"
    which allows to disable tooltips intended for newbies only
    (default: on).
  * Extended support for keyboard function keys up to F19.
  * List assigned scripts as colored tooltip when hovering mouse
    over the "Scripts" column in the instruments list.
  * Added global keyboard accelerator Shift + Backspace for
    dropping all script slots from an instrument.
  * Added option to save as gig v4 file (File -> Properties).
  * Fixed duplicate items in File -> Properties -> "File Format"
    combo box.
  * GIG SOUND FORMAT EXTENSION: Added combo box "Sustain Release
    Trigger" which can be used to optionally play release trigger
    samples on sustain pedal up.
  * GIG SOUND FORMAT EXTENSION: Added check box "No note-off
    release trigger" which allows to disable release trigger
    samples on regular MIDI note-off.
  * Fixed compiler errors with Gtk 3.24.x (patch by Miroslav
    Šulc).
  * Fixed some compiler warnings
  * Avoid non-standard offsetof usage (to get rid of gcc
    warnings)
  * Use GDK Seat API if available to grab pointer
  * Improve version checks for pangomm
  * Fix the instrument list tooltip handling so it doesn't
    generate GTK assertion error messages
  * Use English quotation marks in tooltips instead of German
  * Use multiple columns in controller value popups, as tall
    popup menus work really badly in some GTK environments
  * Avoid deprecated sigc++ usage
  * Fix build on old linux environments
  * Enable "silent rules" in build
  * Fix memory read access bug
  * Refactor code: add common base class for Loader and Saver
  * Fix resource leak: join loader and saver threads after use
  * Use std::thread when building with newer glibmm, as
    Glib::Thread is deprecated
  * Fix bug that left the main window in a greyed out state after
    opening a small gig file
  * Set gtk settings a bit later to prevent warnings
- Spec cleanup
* Wed Feb 21 2018 olaf@aepfle.de
- Update to version 1.1.0
* Tue Mar 28 2017 olaf@aepfle.de
- ExclusiveArch Intel
* Sun Feb 12 2017 olaf@aepfle.de
- Update to version 1.0.0
* Tue Feb 10 2015 avvissu@yandex.ru
- Initial release
